<?php

namespace Cliente\Cliente\Http\Controllers;

use App\Http\Controllers\ResourceController as BaseController;
use Form;
use Cliente\Cliente\Http\Requests\ClienteRequest;
use Cliente\Cliente\Interfaces\ClienteRepositoryInterface;
use Cliente\Cliente\Models\Cliente;

/**
 * Resource controller class for cliente.
 */
class ClienteResourceController extends BaseController
{

    /**
     * Initialize cliente resource controller.
     *
     * @param type ClienteRepositoryInterface $cliente
     *
     * @return null
     */
    public function __construct(ClienteRepositoryInterface $cliente)
    {
        parent::__construct();
        $this->repository = $cliente;
        $this->repository
            ->pushCriteria(\Litepie\Repository\Criteria\RequestCriteria::class)
            ->pushCriteria(\Cliente\Cliente\Repositories\Criteria\ClienteResourceCriteria::class);
    }

    /**
     * Display a list of cliente.
     *
     * @return Response
     */
    public function index(ClienteRequest $request)
    {
        $view = $this->response->theme->listView();

        if ($this->response->typeIs('json')) {
            $function = camel_case('get-' . $view);
            return $this->repository
                ->setPresenter(\Cliente\Cliente\Repositories\Presenter\ClientePresenter::class)
                ->$function();
        }

        $clientes = $this->repository->paginate();

        return $this->response->title(trans('cliente::cliente.names'))
            ->view('cliente::cliente.index', true)
            ->data(compact('clientes'))
            ->output();
    }

    /**
     * Display cliente.
     *
     * @param Request $request
     * @param Model   $cliente
     *
     * @return Response
     */
    public function show(ClienteRequest $request, Cliente $cliente)
    {

        if ($cliente->exists) {
            $view = 'cliente::cliente.show';
        } else {
            $view = 'cliente::cliente.new';
        }

        return $this->response->title(trans('app.view') . ' ' . trans('cliente::cliente.name'))
            ->data(compact('cliente'))
            ->view($view, true)
            ->output();
    }

    /**
     * Show the form for creating a new cliente.
     *
     * @param Request $request
     *
     * @return Response
     */
    public function create(ClienteRequest $request)
    {

        $cliente = $this->repository->newInstance([]);
        return $this->response->title(trans('app.new') . ' ' . trans('cliente::cliente.name')) 
            ->view('cliente::cliente.create', true) 
            ->data(compact('cliente'))
            ->output();
    }

    /**
     * Create new cliente.
     *
     * @param Request $request
     *
     * @return Response
     */
    public function store(ClienteRequest $request)
    {
        try {
            $attributes              = $request->all();
            $attributes['user_id']   = user_id();
            $attributes['user_type'] = user_type();
            $cliente                 = $this->repository->create($attributes);

            return $this->response->message(trans('messages.success.created', ['Module' => trans('cliente::cliente.name')]))
                ->code(204)
                ->status('success')
                ->url(guard_url('cliente/cliente/' . $cliente->getRouteKey()))
                ->redirect();
        } catch (Exception $e) {
            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('/cliente/cliente'))
                ->redirect();
        }

    }

    /**
     * Show cliente for editing.
     *
     * @param Request $request
     * @param Model   $cliente
     *
     * @return Response
     */
    public function edit(ClienteRequest $request, Cliente $cliente)
    {
        return $this->response->title(trans('app.edit') . ' ' . trans('cliente::cliente.name'))
            ->view('cliente::cliente.edit', true)
            ->data(compact('cliente'))
            ->output();
    }

    /**
     * Update the cliente.
     *
     * @param Request $request
     * @param Model   $cliente
     *
     * @return Response
     */
    public function update(ClienteRequest $request, Cliente $cliente)
    {
        try {
            $attributes = $request->all();

            $cliente->update($attributes);
            return $this->response->message(trans('messages.success.updated', ['Module' => trans('cliente::cliente.name')]))
                ->code(204)
                ->status('success')
                ->url(guard_url('cliente/cliente/' . $cliente->getRouteKey()))
                ->redirect();
        } catch (Exception $e) {
            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('cliente/cliente/' . $cliente->getRouteKey()))
                ->redirect();
        }

    }

    /**
     * Remove the cliente.
     *
     * @param Model   $cliente
     *
     * @return Response
     */
    public function destroy(ClienteRequest $request, Cliente $cliente)
    {
        try {

            $cliente->delete();
            return $this->response->message(trans('messages.success.deleted', ['Module' => trans('cliente::cliente.name')]))
                ->code(202)
                ->status('success')
                ->url(guard_url('cliente/cliente/0'))
                ->redirect();

        } catch (Exception $e) {

            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('cliente/cliente/' . $cliente->getRouteKey()))
                ->redirect();
        }

    }

    /**
     * Remove multiple cliente.
     *
     * @param Model   $cliente
     *
     * @return Response
     */
    public function delete(ClienteRequest $request, $type)
    {
        try {
            $ids = hashids_decode($request->input('ids'));

            if ($type == 'purge') {
                $this->repository->purge($ids);
            } else {
                $this->repository->delete($ids);
            }

            return $this->response->message(trans('messages.success.deleted', ['Module' => trans('cliente::cliente.name')]))
                ->status("success")
                ->code(202)
                ->url(guard_url('cliente/cliente'))
                ->redirect();

        } catch (Exception $e) {

            return $this->response->message($e->getMessage())
                ->status("error")
                ->code(400)
                ->url(guard_url('/cliente/cliente'))
                ->redirect();
        }

    }

    /**
     * Restore deleted clientes.
     *
     * @param Model   $cliente
     *
     * @return Response
     */
    public function restore(ClienteRequest $request)
    {
        try {
            $ids = hashids_decode($request->input('ids'));
            $this->repository->restore($ids);

            return $this->response->message(trans('messages.success.restore', ['Module' => trans('cliente::cliente.name')]))
                ->status("success")
                ->code(202)
                ->url(guard_url('/cliente/cliente'))
                ->redirect();

        } catch (Exception $e) {

            return $this->response->message($e->getMessage())
                ->status("error")
                ->code(400)
                ->url(guard_url('/cliente/cliente/'))
                ->redirect();
        }

    }

}
